This part of the project documentation
will focus on an **understanding-oriented** approach.
Here, we will describe the background of the project,
as well as reasoning about how it was implemented.

Points we will aim to cover:

- Context and background on the library
- Why it was created
- Help the reader make connections

We will aim to avoid writing instructions or technical descriptions here,
they belong elsewhere.
